<?php
/*
Plugin Name: Hepsipay Sanal POS
Description: Sanal POS WooCommerce modülü ile sitenizden ödeme almaya başlayın.
Version: 3.0.5
Requires at least: 4.5
Tested up to: 6.5
WC requires at least: 3.6
WC tested up to: 8.2.1
Author: Alttantire Yazılım Çözümleri
Author URI: https://www.alttantire.com
Text Domain: wc_alttantire
Domain Path: /languages/
*/

if ( ! function_exists( 'get_plugin_data' ) ) {
	require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

use Automattic\WooCommerce\Utilities\FeaturesUtil;

if ( ! defined( "ABSPATH" ) ) {
	exit();
}
if ( ! defined( "ALTTANTIRE_PLUGIN_DIR" ) ) {
	define( "ALTTANTIRE_PLUGIN_DIR", dirname( __FILE__ ) );
}

if ( ! defined( "ALTTANTIRE_PLUGIN_ABSOLUTE_PATH" ) ) {
	define( "ALTTANTIRE_PLUGIN_ABSOLUTE_PATH", plugin_dir_url( __FILE__ ) );
}

if ( ! defined( "ALTTANTIRE_PLUGIN_BASE_NAME" ) ) {
	define( "ALTTANTIRE_PLUGIN_BASE_NAME", plugin_basename( __FILE__ ) );
}

if ( ! defined( "ALTTANTIRE_TEXT_DOMAIN" ) ) {
	define( "ALTTANTIRE_TEXT_DOMAIN", "woo_alttantire_hepsipay" );
}

if ( ! defined( "ALTTANTIRE_METHOD_TITLE" ) ) {
	define( "ALTTANTIRE_METHOD_TITLE", "Hepsipay Sanal POS" );
}

if ( ! defined( "ALTTANTIRE_MIN_PHP_VER" ) ) {
	define( 'ALTTANTIRE_MIN_PHP_VER', '7.4.0' );
}

if ( ! defined( "ALTTANTIRE_PLUGIN_VER" ) ) {
	$plugin_path = WP_PLUGIN_DIR . '/' . ALTTANTIRE_PLUGIN_BASE_NAME;
	$plugin_data = get_plugin_data( $plugin_path );
	
	define( 'ALTTANTIRE_PLUGIN_VER', $plugin_data['Version'] ?? "N/A" );
}

if ( WP_DEBUG ) {
	ini_set( "display_errors", 1 );
	ini_set( "display_startup_errors", 1 );
	error_reporting( E_ALL );
}

if ( ! class_exists( "WooHepsipayPayment" ) ) {
	class WooHepsipayPayment {
		
		public function __construct() {
			$this->init();
		}
		
		private function init(): void {
			
			add_action( 'admin_init', [ $this, 'checkWoocommerce' ] );
			
			add_action(
				"plugin_loaded",
				[ $this, "load_alttantire_gateway_classes" ],
				0
			);
			add_filter(
				"plugin_action_links_" . ALTTANTIRE_PLUGIN_BASE_NAME,
				[ $this, "add_setting_link" ]
			);
			
			add_action( "init", [ $this, "init_plugin" ] );
			
			add_action( "before_woocommerce_init", [
				$this,
				"declareCompatibility",
			] );
			
			add_action( "wp_enqueue_scripts", [ $this, "enqueue_assets", ] );
			
			add_action( 'wp_ajax_handle_billing_data', [ 'HepsiPayPlugin', 'handleBillingData' ] );
			add_action( 'wp_ajax_nopriv_handle_billing_data', [ 'HepsiPayPlugin', 'handleBillingData' ] );
			
			add_action( 'wp_ajax_handle_payment_is_success', [ 'HepsiPayPlugin', 'checkPaymentIsSuccess' ] );
			add_action( 'wp_ajax_nopriv_handle_payment_is_success', [ 'HepsiPayPlugin', 'checkPaymentIsSuccess' ] );
			
		}
		
		public function checkWoocommerce(): void {
			
			if ( is_admin() ) {
				$message = null;
				
				if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
					$message = "Sanal POS Payment Gateway requires the WooCommerce plugin to be installed and active.";
				} elseif ( version_compare( phpversion(), ALTTANTIRE_MIN_PHP_VER, '<' ) ) {
					$message = "Web sitenizde PHP " . phpversion() . " Versiyonunu kullanıyorsunuz. ";
					$message .= ALTTANTIRE_METHOD_TITLE . " eklentisi PHP " . ALTTANTIRE_MIN_PHP_VER . " ve üzeri versiyonda çalışır.";
				} elseif (
					! function_exists( 'curl_init' ) &&
					! function_exists( 'file_get_contents' ) &&
					! ini_get( 'allow_url_fopen' ) ) {
					$message = "Sunucunuzda cURL kurulu ya da aktif değil. ";
					$message .= ALTTANTIRE_METHOD_TITLE . " eklentisini kullanabilmeniz için sunucunuzda cURL kurulu olmalıdır. s";
				}
				
				if ( $message ) {
					add_action( 'admin_notices', function() use ( $message ) {
						self::add_notice_for_woocommerce( $message );
					} );
				}
				
			}
			
		}
		
		public static function add_notice_for_woocommerce( $message ) {
			?>
            <div class="notice notice-error is-dismissible">
                <p><strong><?php echo _e(
							$message,
							ALTTANTIRE_TEXT_DOMAIN
						); ?></strong></p>
            </div>
			<?php
		}
		
		/**
		 * Declare compatibility
		 */
		public function declareCompatibility(): void {
			// Check if the required class exists
			
			if ( class_exists( FeaturesUtil::class ) ) {
				// Declare compatibility for 'custom_order_tables'
				FeaturesUtil::declare_compatibility(
					"custom_order_tables",
					__FILE__,
					true
				);
				
				// Declare compatibility for 'cart_checkout_blocks'
				FeaturesUtil::declare_compatibility(
					"cart_checkout_blocks",
					__FILE__,
					false
				);
			}
		}
		
		public function load_alttantire_gateway_classes(): void {
			if ( ! class_exists( "WC_Payment_Gateway" ) ) {
				return;
			}
			
			require_once ALTTANTIRE_PLUGIN_DIR .
			             "/includes/class/HepsiPayPlugin.php";
			
			require_once ALTTANTIRE_PLUGIN_DIR .
			             "/includes/class/HepsiPayGateway.php";
			
			require_once ALTTANTIRE_PLUGIN_DIR .
			             "/includes/class/HepsiPayUtils.php";
			
			add_filter( "woocommerce_payment_gateways", [
				&$this,
				"add_main_gateway",
			] );
		}
		
		public static function add_main_gateway( $methods ) {
			
			$methods[] = HepsiPayPlugin::class;
			
			return $methods;
		}
		
		public static function add_setting_link( $links ) {
			array_unshift(
				$links,
				'<a href="' .
				admin_url(
					"admin.php?page=wc-settings&tab=checkout&section=woo_alttantire_hepsipay"
				) .
				'">' .
				__( "Ayarlar", ALTTANTIRE_TEXT_DOMAIN ) .
				"</a>"
			);
			
			return $links;
		}
		
		public function enqueue_assets(): void {
			
			wp_register_script(
				"alttantire-hepsipay-gateway-init",
				WP_PLUGIN_URL .
				"/woo-alttantire-hepsipay-gateway/assets/js/init.js",
				[],
				false,
				true
			);
			wp_enqueue_script( "alttantire-hepsipay-gateway-init" );
			
			wp_register_script(
				"alttantire-hepsipay-gateway-ajax-handle",
				WP_PLUGIN_URL .
				"/woo-alttantire-hepsipay-gateway/assets/js/handler.js",
				[],
				false,
				true
			);
			wp_enqueue_script( "alttantire-hepsipay-gateway-ajax-handle" );
			wp_localize_script( "alttantire-hepsipay-gateway-ajax-handle", "data_object", [
				"url" => admin_url( "admin-ajax.php" ),
			
			] );
			
			wp_register_style(
				"alttantire-gateway-payment-style",
				WP_PLUGIN_URL .
				"/woo-alttantire-hepsipay-gateway/assets/css/style.css",
				[],
				"3.0.0",
				"all"
			);
			wp_enqueue_style( "alttantire-gateway-payment-style" );
		}
		
		public function init_plugin(): void {
			if ( ! session_id() ) {
				session_start();
			}
			
			load_plugin_textdomain(
				ALTTANTIRE_TEXT_DOMAIN,
				false,
				dirname( plugin_basename( __FILE__ ) ) . "/languages/"
			);
		}
	}
	
	new WooHepsipayPayment();
}
